
***************************
* File: date_livraison.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\Second Round\phagedis\date_livraison.dta"


**************************************************
***    Ensure all variables are present and labeled.
**************************************************
cd "Source\Extra\Second Round\phagedis"
log using "date_livraison", replace
codebook, compact
log close


**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "date_livraison label values", replace

**************************************************
***   Unique identifiers: ID
**************************************************

egen  fivondronana_code=group( fivondronana)
label var  fivondronana_code " fivondronana code"
order  fivondronana  fivondronana_code
egen  commune_code=group( commune)
label var  commune_code " commune code"
order  commune  commune_code

egen ID=concat(  fivondronana_code commune_code csb_code)
destring ID, replace
order  ID 
label var ID "identifiant unique"

**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

log using "date_livraison label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************

mvdecode _all, mv(0 = .z)
grubbs  per_phag val_tot1 sur_phag1 tot1 val_tot2 sur_phag2 tot2, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\phagedis"
log using "date_livraison codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\phagedis"
save date_livraison_cleaned_data.dta, replace
