
***************************
* File: situation_livraison.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\Second Round\phagedis\situation_livraison.dta"


**************************************************
***  Ensure all variables are present and labeled.
**************************************************
cd "Source\Second Round\phagedis"
log using "situation_livraison", replace
codebook, compact
log close

**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "situation_livraison label values", replace

**************************************************
***   Unique identifiers: ID
**************************************************

egen  fivondronana_code=group( fivondronana)
label var  fivondronana_code " fivondronana code"
order  fivondronana  fivondronana_code
egen  commune_code=group( commune)
label var  commune_code " commune code"
order  commune  commune_code

egen ID=concat(  fivondronana_code commune_code csb_code)
destring ID, replace
order  ID 
label var ID "identifiant unique"

*Destring typ_med
gen typ_med2=	1	if typ_med==	"a"
replace typ_med2=	2	if typ_med==	"b"
replace typ_med2=	3	if typ_med==	"c"
replace typ_med2=	4	if typ_med==	"d"
replace typ_med2=	5	if typ_med==	"e"
replace typ_med2=	6	if typ_med==	"f"
replace typ_med2=	7	if typ_med==	"g"
replace typ_med2=	8	if typ_med==	"h"
replace typ_med2=	9	if typ_med==	"i"
replace typ_med2=	10	if typ_med==	"j"
replace typ_med2=	11	if typ_med==	"k"
replace typ_med2=	12	if typ_med==	"l"
replace typ_med2=	13	if typ_med==	"m"
replace typ_med2=	14	if typ_med==	"n"
replace typ_med2=	15	if typ_med==	"o"
replace typ_med2=	16	if typ_med==	"p"
replace typ_med2=	17	if typ_med==	"q"
replace typ_med2=	18	if typ_med==	"r"
replace typ_med2=	19	if typ_med==	"s"
replace typ_med2=	20	if typ_med==	"t"
replace typ_med2=	21	if typ_med==	"u"
drop typ_med
rename typ_med2 typ_med

local mylist "  condition qte_com1 prix1 qte_liv1 valeur1 qte_com2 prix2 qte_liv2 valeur2"
levelsof  typ_med, local( typ_med_levels)
foreach v of varlist  condition qte_com1 prix1 qte_liv1 valeur1 qte_com2 prix2 qte_liv2 valeur2{
local l`v' : variable label `v'
}
reshape wide condition qte_com1 prix1 qte_liv1 valeur1 qte_com2 prix2 qte_liv2 valeur2, i( ID) j( typ_med)
foreach x of local mylist{
foreach y of local  typ_med_levels{
label var `x'`y' "`l`x''"
}
}

**************************************************
***    Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 


**************************************************
***    Identify outliers
**************************************************

mvdecode _all, mv(0 = .z)
grubbs  condition* qte_com1* prix1* qte_liv1* valeur1* qte_com2* prix2* qte_liv2* valeur2*, level(99.99)
sum grubbs*
drop grubbs* 
mvencode _all, mv(.z = 0)


**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\phagedis"
log using "situation_livraison codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\phagedis"
save situation_livraison_cleaned_data.dta, replace
